@@ -131,8 +131,8 @@ finish(isc_task_t *task, isc_event_t *event) {
 	sync_barrierev_t *bev = NULL;
 	sync_state_t new_state;
 
-	REQUIRE(ISCAPI_TASK_VALID(task));
 	REQUIRE(event != NULL);
+	UNUSED(task);
 
 	bev = (sync_barrierev_t *)event;
 	log_debug(1, "sync_barrier_wait(): finish reached");
@@ -156,7 +156,7 @@ finish(isc_task_t *task, isc_event_t *event) {
 	BROADCAST(&bev->sctx->cond);
 	UNLOCK(&bev->sctx->mutex);
 	if (new_state == sync_finished)
-		activate_zones(task, bev->inst);
+		activate_zones(bev->inst);
 
 	if (result != ISC_R_SUCCESS)
 		log_error_r("syncrepl finish() failed");
@@ -206,8 +206,8 @@ barrier_decrement(isc_task_t *task, isc_event_t *event) {
 	sync_barrierev_t *bev = NULL;
 	uint32_t cnt;
 
-	REQUIRE(ISCAPI_TASK_VALID(task));
 	REQUIRE(event != NULL);
+	UNUSED(task);
 
 	bev = (sync_barrierev_t *)event;
 #if LIBDNS_VERSION_MAJOR < 1600
@@ -458,7 +458,6 @@ sync_task_add(sync_ctx_t *sctx, isc_task_t *task) {
 	uint32_t cnt;
 
 	REQUIRE(sctx != NULL);
-	REQUIRE(ISCAPI_TASK_VALID(task));
 
 	newel = isc_mem_get(sctx->mctx, sizeof(*(newel)));
 	ZERO_PTR(newel);
