@@ -6,6 +6,7 @@
 #define _LD_TYPES_H_
 
 #include <isc/event.h>
+#include <inttypes.h>
 #include <isc/refcount.h>
 #include <dns/name.h>
 
@@ -24,7 +25,7 @@
  * rdata1 -> rdata2 -> rdata3           rdata4 -> rdata5
  * next_rdatalist              ->       next_rdatalist  ...
  */
-typedef LIST(dns_rdatalist_t) ldapdb_rdatalist_t;
+typedef ISC_LIST(dns_rdatalist_t) ldapdb_rdatalist_t;
 
 typedef struct enum_txt_assoc {
 	int		value;
@@ -47,7 +48,7 @@ struct ldap_syncreplevent {
 	char *prevdn;
 	int chgtype;
 	ldap_entry_t *entry;
-	isc_uint32_t seqid;
+	uint32_t seqid;
 };
 
 #endif /* !_LD_TYPES_H_ */
